==> haskell-x509-validation-1.6.12-26-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-x509-validation.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 x509-validation
version:              1.6.12
visibility:           public
id:                   x509-validation-1.6.12-AL3LT9AnbU57voscsaO4Mn
key:                  x509-validation-1.6.12-AL3LT9AnbU57voscsaO4Mn
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Vincent Hanquez <vincent@snarc.org>
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             http://github.com/vincenthz/hs-certificate
synopsis:             X.509 Certificate and CRL validation
description:          X.509 Certificate and CRL validation. please see README
category:             Data
abi:                  5de2f98c83c87dc66674873e46d57127
exposed:              True
exposed-modules:      Data.X509.Validation
hidden-modules:
    Data.X509.Validation.Signature Data.X509.Validation.Fingerprint
    Data.X509.Validation.Cache Data.X509.Validation.Types

import-dirs:          /usr/lib/ghc-9.0.2/site-local/x509-validation-1.6.12
library-dirs:         /usr/lib/ghc-9.0.2/site-local/x509-validation-1.6.12
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-x509-validation
hs-libraries:         HSx509-validation-1.6.12-AL3LT9AnbU57voscsaO4Mn
depends:
    asn1-encoding-0.9.6-Ez6kIfPKcVuCgWyQ6Ekrp8
    asn1-types-0.3.4-3L44gqHcVAjAn4ZvPOhbQl base-4.15.1.0
    bytestring-0.10.12.1 containers-0.6.4.1
    cryptonite-0.30-8WpJqUEqVEI3rPOWmk32tZ
    data-default-class-0.1.2.0-IxhEAzgy8931aXcEiJcyZO
    hourglass-0.2.12-9LBhaOjJNv66qaT7fwXpZK
    memory-0.17.0-CJJwCTl3QuwCxlJovCa0Bf mtl-2.2.2
    pem-0.2.4-LfBtzthKaoTCkOxSw8AX6k x509-1.7.6-7n2ZI0o8drkIhJtPmM1q62
    x509-store-1.6.9-2F26Qq0TAMpyoZLahTyfU

haddock-interfaces:
    /usr/share/doc/haskell-x509-validation/html/x509-validation.haddock

haddock-html:         /usr/share/doc/haskell-x509-validation/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-x509-validation-1.6.12-28-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-x509-validation.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 x509-validation
version:              1.6.12
visibility:           public
id:                   x509-validation-1.6.12-5viYfCi3fAV1lFGH0WW2Vy
key:                  x509-validation-1.6.12-5viYfCi3fAV1lFGH0WW2Vy
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Vincent Hanquez <vincent@snarc.org>
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             http://github.com/vincenthz/hs-certificate
synopsis:             X.509 Certificate and CRL validation
description:          X.509 Certificate and CRL validation. please see README
category:             Data
abi:                  7d1a0b8da745a505d1f05af3e1cfcf9b
exposed:              True
exposed-modules:      Data.X509.Validation
hidden-modules:
    Data.X509.Validation.Signature Data.X509.Validation.Fingerprint
    Data.X509.Validation.Cache Data.X509.Validation.Types

import-dirs:          /usr/lib/ghc-9.0.2/site-local/x509-validation-1.6.12
library-dirs:         /usr/lib/ghc-9.0.2/site-local/x509-validation-1.6.12
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-x509-validation
hs-libraries:         HSx509-validation-1.6.12-5viYfCi3fAV1lFGH0WW2Vy
depends:
    asn1-encoding-0.9.6-6DQYtI95QVpEbmwpsK1Kha
    asn1-types-0.3.4-7bMDspfMtIvFLLR9MCad4N base-4.15.1.0
    bytestring-0.10.12.1 containers-0.6.4.1
    cryptonite-0.30-6WS01g2u04J8So84eVPTvN
    data-default-class-0.1.2.0-IxhEAzgy8931aXcEiJcyZO
    hourglass-0.2.12-Buee3Jo9ubkEaeYvU0d8b3
    memory-0.17.0-CJJwCTl3QuwCxlJovCa0Bf mtl-2.2.2
    pem-0.2.4-DxGuhP5cfPt25XJyt2SCCA x509-1.7.6-u9unt1HFxY3LKG4Qba0XM
    x509-store-1.6.9-6m8olS32JZpIFPtNsSL8Ov

haddock-interfaces:
    /usr/share/doc/haskell-x509-validation/html/x509-validation.haddock

haddock-html:         /usr/share/doc/haskell-x509-validation/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
